@@ -1,6 +1,5 @@
 Pyrone_tr = {
 'AJAX_REQUEST_ERROR': 'Ошибка выполнения AJAX-запроса',
-'ARTICLE_NOT_SAVED': 'Ошибка сохранения.',
 'ARTICLE_SAVED': 'Статья сохранена.',
 'BACKUP_RESTORE_COMPLETE': 'Бэкап успешно восстановлен',
 'COMMENT_BODY_IS_REQUIRED': 'Текст комментария обязателен',
@@ -10,6 +9,7 @@ Pyrone_tr = {
 'FIELD_MUST_BE_ALPHA_NUM': 'Поле должно содержать только буквенно-цифровые символы',
 'FILE_NAME_ALREADY_EXISTS_IN_THE_STORAGE': 'Файл с таким именем уже есть в хранилище',
 'PASSWORDS_DONT_MATCH': 'Пароли не совпадают',
+'POSTING_COMMENT': 'Отправка комментария',
 'SELECT_FILE_TO_UPLOAD': 'Выберите файл для загрузки',
 'SELECT_ITEMS_FIRST': 'Сначала выберите элементы',
 'SETTINGS_SAVED': 'Настройки успешно сохранены',
