@@ -1,13 +1,15 @@
 import unittest
-from pyramid.config import Configurator
+#from pyramid.config import Configurator
 from pyramid import testing
 
+
 def _initTestingDB():
     from sqlalchemy import create_engine
     from pyrone.models import initialize_sql
     session = initialize_sql(create_engine('sqlite://'))
     return session
 
+
 class TestMyView(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
